@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "crc" "1.1.2"
+(define-package "crc" "20250303.119"
   "Cyclic Redundancy Check."
   '((emacs "25.1"))
   :url "https://codeberg.org/tomenzgg/Emacs-CRC"
